@@ -1,4 +1,4 @@
-/* ID: interface.h, last updated 2023-05-17, F.Osorio */
+/* ID: interface.h, last updated 2024-01-03, F.Osorio */
 
 #ifndef L1PACK_INTERFACE_H
 #define L1PACK_INTERFACE_H
@@ -6,6 +6,9 @@
 /* basic matrix manipulations */
 extern void ax_plus_y(double, double *, int, double *, int, int);
 extern void copy_mat(double *, int, double *, int, int, int);
+extern void copy_lower(double *, int, double *, int, int);
+extern void copy_vec(double *, int, double *, int, int);
+extern double dot_product(double *, int, double *, int, int);
 extern void GAXPY(double *, double, double *, int, int, int, double *, double);
 extern double logAbsDet(double *, int, int);
 extern void mult_triangular_vec(double *, int, int, char *, char *, char *, double *, int);
@@ -25,7 +28,14 @@ extern void QR_qty(double *, int, int, int, double *, double *, int, int, int, i
 /* triangular solver */
 extern void backsolve(double *, int, int, double *, int, int, int *);
 
+/* descriptive statistics */
+extern void center_and_Scatter(double *, int, int, double *, double *, double *);
+extern void center_online(double *, int, int, double *, double *);
+
 /* Mahalanobis distance */
 extern double mahalanobis(double *, int, double *, double *);
 
+/* Wilson-Hilferty transformation */
+extern void WH_Laplace(double *, int, int, double *);
+
 #endif /* L1PACK_INTERFACE_H */
